@@ -40,6 +40,7 @@ class LocalClassifierPerParentNode(BaseEstimator, HierarchicalClassifier):
         edge_list: str = None,
         replace_classifiers: bool = True,
         n_jobs: int = 1,
+        bert: bool = False,
     ):
         """
         Initialize a local classifier per parent node.
@@ -60,6 +61,9 @@ class LocalClassifierPerParentNode(BaseEstimator, HierarchicalClassifier):
             a single unique class.
         n_jobs : int, default=1
             The number of jobs to run in parallel. Only :code:`fit` is parallelized.
+            If :code:`Ray` is installed it is used, otherwise it defaults to :code:`Joblib`.
+        bert : bool, default=False
+            If True, skip scikit-learn's checks and sample_weight passing for BERT.
         """
         super().__init__(
             local_classifier=local_classifier,
@@ -68,9 +72,10 @@ class LocalClassifierPerParentNode(BaseEstimator, HierarchicalClassifier):
             replace_classifiers=replace_classifiers,
             n_jobs=n_jobs,
             classifier_abbreviation="LCPPN",
+            bert=bert,
         )
 
-    def fit(self, X, y):
+    def fit(self, X, y, sample_weight=None):
         """
         Fit a local classifier per parent node.
 
@@ -82,6 +87,9 @@ class LocalClassifierPerParentNode(BaseEstimator, HierarchicalClassifier):
             converted into a sparse ``csc_matrix``.
         y : array-like of shape (n_samples, n_levels)
             The target values, i.e., hierarchical class labels for classification.
+        sample_weight : array-like of shape (n_samples,), default=None
+            Array of weights that are assigned to individual samples.
+            If not provided, then each sample is given unit weight.
 
         Returns
         -------
@@ -89,7 +97,7 @@ class LocalClassifierPerParentNode(BaseEstimator, HierarchicalClassifier):
             Fitted estimator.
         """
         # Execute common methods necessary before fitting
-        super()._pre_fit(X, y)
+        super()._pre_fit(X, y, sample_weight)
 
         # Fit local classifiers in DAG
         super().fit(X, y)
@@ -124,7 +132,10 @@ class LocalClassifierPerParentNode(BaseEstimator, HierarchicalClassifier):
         check_is_fitted(self)
 
         # Input validation
-        X = check_array(X, accept_sparse="csr")
+        if not self.bert:
+            X = check_array(X, accept_sparse="csr")
+        else:
+            X = np.array(X)
 
         # Initialize array that holds predictions
         y = np.empty((X.shape[0], self.max_levels_), dtype=self.dtype_)
@@ -186,20 +197,26 @@ class LocalClassifierPerParentNode(BaseEstimator, HierarchicalClassifier):
             else:
                 y.append(row[np.where(row == node)[0][0] + 1])
         y = np.array(y)
-        return X, y
+        sample_weight = (
+            self.sample_weight_[mask] if self.sample_weight_ is not None else None
+        )
+        return X, y, sample_weight
 
     @staticmethod
     def _fit_classifier(self, node):
         classifier = self.hierarchy_.nodes[node]["classifier"]
         # get children examples
-        X, y = self._get_successors(node)
+        X, y, sample_weight = self._get_successors(node)
         unique_y = np.unique(y)
         if len(unique_y) == 1 and self.replace_classifiers:
             classifier = ConstantClassifier()
-        classifier.fit(X, y)
+        if not self.bert:
+            classifier.fit(X, y, sample_weight)
+        else:
+            classifier.fit(X, y)
         return classifier
 
-    def _fit_digraph(self, local_mode: bool = False):
+    def _fit_digraph(self, local_mode: bool = False, use_joblib: bool = False):
         self.logger_.info("Fitting local classifiers")
         nodes = self._get_parents()
-        self._fit_node_classifier(nodes, local_mode)
+        self._fit_node_classifier(nodes, local_mode, use_joblib)
